@@ -1,33 +1,32 @@
-from collections import defaultdict, namedtuple, OrderedDict
+from collections import OrderedDict, defaultdict, namedtuple
 from types import GeneratorType
 
+from django import VERSION as DJANGO_VERSION
+from django.core.exceptions import (ImproperlyConfigured,
+                                    MultipleObjectsReturned)
 from django.db import models
 from django.db.models import BooleanField, Case, Q, When
-from django.core.exceptions import ImproperlyConfigured, MultipleObjectsReturned
-from django.http import HttpRequest
 from django.template.loader import get_template, select_template
 from django.utils.functional import cached_property, lazy
 from django.utils.safestring import mark_safe
 from django.utils.translation import gettext_lazy as _
 from modelcluster.models import ClusterableModel
-try:
-    from wagtail import hooks
-    from wagtail.models import Page, Site
-except ImportError:
-    from wagtail.core import hooks
-    from wagtail.core.models import Page, Site
-
+from wagtail import hooks
+from wagtail.models import Page, Site
 
 from wagtailmenus import forms, panels
 from wagtailmenus.conf import constants, settings
 from wagtailmenus.errors import RequestUnavailableError
 from wagtailmenus.utils.misc import get_fake_request, get_site_from_request
+
 from .menuitems import MenuItem
 from .mixins import DefinesSubMenuTemplatesMixin
 from .pages import AbstractLinkPage
 
-
-mark_safe_lazy = lazy(mark_safe, str)
+if DJANGO_VERSION >= (4, 1):
+    mark_safe_lazy = mark_safe
+else:
+    mark_safe_lazy = lazy(mark_safe, str)
 
 ContextualVals = namedtuple('ContextualVals', (
     'parent_context',
@@ -498,6 +497,8 @@ class Menu:
 
         if option_vals.apply_active_classes:
             if page:
+                if (page.pk != page.localized.pk):
+                    page = page.localized
                 if(current_page and page.pk == current_page.pk):
                     # This is the current page, so the menu item should
                     # probably have the 'active' class
@@ -1178,6 +1179,15 @@ class AbstractFlatMenu(DefinesSubMenuTemplatesMixin, MenuWithMenuItems):
         verbose_name = _("flat menu")
         verbose_name_plural = _("flat menus")
 
+    def handle_formatted(self):
+        return mark_safe(f'<code>{self.handle}</code>')
+    handle_formatted.short_description = _('handle')
+    handle_formatted.admin_order_field = 'handle'
+
+    def items(self):
+        return self.get_menu_items_manager().count()
+    items.short_description = _('no. of items')
+
     @classmethod
     def render_from_tag(
         cls, context, handle, fall_back_to_default_site_menus=True,
