@@ -10,7 +10,7 @@ DATABASES = {
     }
 }
 
-INSTALLED_APPS += (
+INSTALLED_APPS += (  # NOQA
     'wagtailmenus.tests',
 )
 
@@ -18,3 +18,5 @@ ROOT_URLCONF = 'wagtailmenus.tests.urls'
 WAGTAIL_SITE_NAME = 'Wagtailmenus Test'
 LOGIN_URL = 'wagtailadmin_login'
 LOGIN_REDIRECT_URL = 'wagtailadmin_home'
+WAGTAILADMIN_BASE_URL = 'http://localhost:8000'
+DEFAULT_AUTO_FIELD = 'django.db.models.AutoField'
