@@ -1,12 +1,10 @@
 from bs4 import BeautifulSoup
 from django.test import TestCase, override_settings
+from wagtail.models import Site
+
 from wagtailmenus.errors import SubMenuUsageError
-from wagtailmenus.models import MainMenu, FlatMenu
+from wagtailmenus.models import FlatMenu, MainMenu
 from wagtailmenus.templatetags.menu_tags import validate_supplied_values
-try:
-    from wagtail.models import Site
-except ImportError:
-    from wagtail.core.models import Site
 
 
 class TestTemplateTags(TestCase):
@@ -115,7 +113,7 @@ class TestTemplateTags(TestCase):
         Test '{{ main_menu }}' output for homepage
         """
         response = self.client.get('/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='main-menu-two-levels').decode()
@@ -159,7 +157,7 @@ class TestTemplateTags(TestCase):
         Test '{{ main_menu max_levels=3 }}' output for homepage
         """
         response = self.client.get('/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='main-menu-three-levels').decode()
@@ -210,7 +208,7 @@ class TestTemplateTags(TestCase):
         Test '{{ main_menu use_absolute_page_urls=True }}' output for homepage
         """
         response = self.client.get('/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='main-menu-absolute-url').decode()
@@ -278,7 +276,7 @@ class TestTemplateTags(TestCase):
         Test '{% children_menu %}' output for homepage
         """
         response = self.client.get('/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
         menu_html = soup.find(id='children-menu-one-level').decode()
         expected_menu_html = """
         <div id="children-menu-one-level">
@@ -297,7 +295,7 @@ class TestTemplateTags(TestCase):
         Test '{% children_menu max_levels=3 allow_repeating_parents=False %}' output for homepage
         """
         response = self.client.get('/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
         menu_html = soup.find(id='children-menu-three-levels').decode()
         expected_menu_html = """
         <div id="children-menu-three-levels">
@@ -343,7 +341,7 @@ class TestTemplateTags(TestCase):
         Test '{% children_menu use_absolute_page_urls=True %}' output for homepage
         """
         response = self.client.get('/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
         menu_html = soup.find(id='children-menu-absolute-url').decode()
         expected_menu_html = """
         <div id="children-menu-absolute-url">
@@ -370,7 +368,7 @@ class TestTemplateTags(TestCase):
         Test '{% main_menu %}' output for 'About us' page
         """
         response = self.client.get('/about-us/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='main-menu-two-levels').decode()
@@ -414,7 +412,7 @@ class TestTemplateTags(TestCase):
         Test '{% main_menu max_levels=3 %}' output for 'About us' page
         """
         response = self.client.get('/about-us/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='main-menu-three-levels').decode()
@@ -467,7 +465,7 @@ class TestTemplateTags(TestCase):
                 Test '{{ main_menu use_absolute_page_urls=True }}' output for homepage
                 """
         response = self.client.get('/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='main-menu-absolute-url').decode()
@@ -535,7 +533,7 @@ class TestTemplateTags(TestCase):
         Test '{% section_menu %}' output for 'About us' page
         """
         response = self.client.get('/about-us/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='section-menu-two-levels').decode()
@@ -566,7 +564,7 @@ class TestTemplateTags(TestCase):
         Test '{% section_menu max_levels=1 %}' output for 'About us' page
         """
         response = self.client.get('/about-us/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='section-menu-one-level').decode()
@@ -590,7 +588,7 @@ class TestTemplateTags(TestCase):
         Test '{% section_menu use_absolute_page_urls=True %}' output for 'About us' page
         """
         response = self.client.get('/about-us/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='section-menu-absolute-url').decode()
@@ -633,7 +631,7 @@ class TestTemplateTags(TestCase):
         Test '{{ sub_menu self }}' output for 'About us' page
         """
         response = self.client.get('/about-us/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
         menu_html = soup.find(id='children-menu-one-level').decode()
         expected_menu_html = """
         <div id="children-menu-one-level">
@@ -652,7 +650,7 @@ class TestTemplateTags(TestCase):
         Test '{% children_menu max_levels=3 allow_repeating_parents=False %}' output for 'About us' page
         """
         response = self.client.get('/about-us/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
         menu_html = soup.find(id='children-menu-three-levels').decode()
         expected_menu_html = """
         <div id="children-menu-three-levels">
@@ -677,7 +675,7 @@ class TestTemplateTags(TestCase):
         Test '{{ sub_menu self }}' output for 'About us' page
         """
         response = self.client.get('/about-us/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
         menu_html = soup.find(id='children-menu-absolute-urls').decode()
         expected_menu_html = """
         <div id="children-menu-absolute-urls">
@@ -704,7 +702,7 @@ class TestTemplateTags(TestCase):
         Test '{% section_menu %}' output for 'Marvel comics' page
         """
         response = self.client.get('/superheroes/marvel-comics/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         menu_html = soup.find(id='section-menu-two-levels').decode()
         expected_menu_html = """
@@ -739,7 +737,7 @@ class TestTemplateTags(TestCase):
         Test '{% section_menu max_levels=1 %}' output for 'Marvel comics' page
         """
         response = self.client.get('/superheroes/marvel-comics/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='section-menu-one-level').decode()
@@ -761,7 +759,7 @@ class TestTemplateTags(TestCase):
         Test '{% section_menu use_absolute_page_urls=True %}' output for 'Marvel comics' page
         """
         response = self.client.get('/superheroes/marvel-comics/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='section-menu-absolute-url').decode()
@@ -803,7 +801,7 @@ class TestTemplateTags(TestCase):
         Test that the HTML output by the 'flat_menu' tag (when using the handle 'contact') renders as expected.
         """
         response = self.client.get('/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='nav-contact').decode()
@@ -815,7 +813,7 @@ class TestTemplateTags(TestCase):
         Test that the HTML output by the 'flat_menu' tag (when using the handle 'footer') renders as expected.
         """
         response = self.client.get('/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='nav-footer').decode()
@@ -835,7 +833,7 @@ class TestTemplateTags(TestCase):
         self.assertHTMLEqual(menu_html, expected_menu_html)
 
         response = self.client.get('/legal/privacy-policy/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='nav-footer').decode()
@@ -855,7 +853,7 @@ class TestTemplateTags(TestCase):
         self.assertHTMLEqual(menu_html, expected_menu_html)
 
         response = self.client.get('/about-us/meet-the-team/custom-url/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='nav-footer').decode()
@@ -875,7 +873,7 @@ class TestTemplateTags(TestCase):
         self.assertHTMLEqual(menu_html, expected_menu_html)
 
         response = self.client.get('/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='nav-footer-absolute-urls').decode()
@@ -904,7 +902,7 @@ class TestTemplateTags(TestCase):
 
     def test_custom_page_menu_output(self):
         response = self.client.get('/custom-url/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         main_menu_html = soup.find(id='main-menu-two-levels').decode()
         expected_menu_html = """
@@ -955,7 +953,7 @@ class TestTemplateTags(TestCase):
         'ancestors', as indicated by the request path.
         """
         response = self.client.get('/about-us/meet-the-team/custom-url/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='section-menu-two-levels').decode()
@@ -992,7 +990,7 @@ class TestTemplateTags(TestCase):
         """
         response = self.client.get('/about-us/meet-the-team/custom-url/')
         self.assertEqual(response.status_code, 200)
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='main-menu-two-levels').decode()
@@ -1041,7 +1039,7 @@ class TestTemplateTags(TestCase):
         """
         response = self.client.get('/superheroes/marvel-comics/custom-man/about/')
         self.assertEqual(response.status_code, 200)
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='section-menu-two-levels').decode()
@@ -1082,7 +1080,7 @@ class TestTemplateTags(TestCase):
         the page is identified using the request path.
         """
         response = self.client.get('/about-us/meet-the-team/staff-member-one/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='main-menu-three-levels').decode()
@@ -1140,7 +1138,7 @@ class TestTemplateTags(TestCase):
         the page is identified using the request path.
         """
         response = self.client.get('/about-us/meet-the-team/staff-member-one/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='section-menu-two-levels').decode()
@@ -1177,7 +1175,7 @@ class TestTemplateTags(TestCase):
         """
         response = self.client.get('/news-and-events/')
 
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='section-menu-two-levels').decode()
@@ -1209,7 +1207,7 @@ class TestTemplateTags(TestCase):
         is used to specify different templates for each level
         """
         response = self.client.get('/')
-        soup = BeautifulSoup(response.content, 'html5lib')
+        soup = BeautifulSoup(response.content, 'html.parser')
 
         # Assertions to compare rendered HTML against expected HTML
         menu_html = soup.find(id='main-menu-sub-menu-templates').decode()
